@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd wt snd_wt listener open_node);
 
-our $VERSION = '0.09';
+our $VERSION = '0.08';
 
 use Carp;
 use IO::Select;
@@ -526,15 +526,6 @@ Connecting to the remote node is done with 'open_node' subprogram:
 
  my $vpid = open_node($host, $port);
 
-To detect connection closing message NODE_CLOSED handler should be defined:
-
- msg NODE_CLOSED => sub { 
- 	my ($vpid) = @_;
- 	...
- };
-
-This statement is true for both the client and the server.
-
 =head1 EXAMPLES
 
 =head2 Ping Pong
@@ -717,10 +708,6 @@ Waiting for a response to a specific message.
  	};
  };
 
-=head1 DEMO
-
-See directory demo.
-
 =head1 REALISATIONS
 
 =over
@@ -739,80 +726,6 @@ L<IPC::MPS::EV> based on L<EV>.
 
 =back
 
-=head1 Compatibility with Event, EV, AnyEvent based modules
-
-IPC::MPS::Event and IPC::MPS::EV allows usage of side modules based on Event, EV modules accordingly (directly or thru AnyEvent). 
-
-=head2 Timer
-
- use IPC::MPS::Event;
- use Event;
- 
- my $vpid = spawn {
- 	receive {
- 		msg ping => sub {
- 			my ($from, $hello) = @_;
- 			print "$hello; $$\n";
- 			Event->timer(after => 1, cb => sub {
- 				snd($from, "pong", "hy");
- 			});
- 		};
- 	};
- };
- 
- snd($vpid, "ping", "hello");
- 
- receive {
- 	msg pong => sub {
- 		my ($from, $hello) = @_;
- 		print "$hello; $$\n";
- 		print "EXIT\n";
- 		exit;
- 	};
- };
-
-=head2 AnyEvent::HTTP
-
- use IPC::MPS::Event;
- use AnyEvent::HTTP;
- 
- my $vpid = spawn {
- 	receive {
- 		msg req => sub {
- 			my ($from, $url) = @_;
- 			http_get $url, sub { 
- 				print ${$_[1]}{URL}, "\t", ${$_[1]}{Status}, "; $$\n";
- 				snd($from, "res", $url, ${$_[1]}{Status});
- 			};
- 		};
- 	};
- };
- 
- snd($vpid, "req", "http://localhost/");
- 
- receive {
- 	msg res => sub {
- 		my ($from, $url, $status) = @_;
- 		print "$url\t$status; $$\n";
- 		print "EXIT\n";
- 		exit;
- 	};
- };
-
-=head2 EV note
-
-Using EV based modules one should call EV::loop clearly:
-
- use IPC::MPS::EV;
- use AnyEvent::HTTP;
- ...
- 			http_get $url, sub { 
- 				print ${$_[1]}{URL}, "\t", ${$_[1]}{Status}, "; $$\n";
- 				snd($from, "res", $url, ${$_[1]}{Status});
- 			};
-			use EV; EV::loop;
- ...
-
 =head1 SEE ALSO
 
 Sometimes it is easier to use a module L<BGS> - Background execution of subroutines in child processes.
